@@ -13,7 +13,8 @@ class Workspace(object):
         workspace_id,
         replaceLocalhostString
     ):
-        self.endpoint = endpoint
+        self.replaceLocalhostString = replaceLocalhostString
+        self.endpoint = self._replace_localhost(endpoint)
         self.headers = headers
         self.workspace_id = workspace_id
         request = Request(
@@ -38,4 +39,10 @@ class Workspace(object):
             cache_refresh=cache_refresh,
             cache_ttl=cache_ttl,
             data_format=data_format
-        )
\ No newline at end of file
+        )
+
+    def _replace_localhost(self, url):
+        if (self.replaceLocalhostString != None):
+            return url.replace('localhost', self.replaceLocalhostString).replace('127.0.0.1', self.replaceLocalhostString)
+        else:
+            return url;
\ No newline at end of file
